==> epo-0.1.0.crate: epo-0.1.0/g.sh <==
#! /bin/sh

# gaze -c 'cargo run -- +9 +0 -0500 0 1 100 1000 1970-01-01T00:00:00 1970-01-01T09:00:00 1970-01-01T09:00:00+0900 1970-01-01T00:00:00+0900 "1970/01/01T09:00:00+0000" "2020-04-18T09:00:00+0000" "2020-04-18T09:00:00+0900"' "src/**/*.rs"

# gaze -c 'cargo run' "src/**/*.rs"

# gaze -c 'cargo run -- +9 +0 -0500 0 "2020-04-18T09:00:00+0000"' "src/**/*.rs"

# gaze -c 'cargo run -- +9 +0 -0500 0 "2020-04-18T09:00:00+0000"' "src/**/*.rs"

# gaze -c 'cargo run -- 1650647334 1650647334-3600 1650647334-3600*10' "src/**/*.rs"

# gaze -c 'cargo run -- "now()"' "src/**/*.rs"

# gaze -c 'cargo run -- "array.extract(2..8)"' "src/**/*.rs"

# gaze -c 'ecargo run "[1..10].map(|x| 1650653482 + x * 86400 )"

# gaze -c 'cargo run -- "2022-02-01" "2022-03-01" "2022-04-01" +9 +8 +7 -4 -5 new_y phoe "[1,2,3,4,5]" ' "src/**/*.rs"


# gaze -c 'cargo run -- "[1,2,3,4,5]" ' "src/**/*.rs"
# gaze -c 'cargo run -- "[1,2,3,4,5].map(a=>1650984906+a*86400)" ' "src/**/*.rs"
# gaze -c 'cargo run -- -p "[1,2,3,4,5].map(a=>1650984906+a*86400)" ' "src/**/*.rs"

# gaze -c 'cargo run -- "now" ' "src/**/*.rs"
# gaze -c 'cargo run -- "now*now" ' "src/**/*.rs"
# gaze -c 'cargo run -- -h' "src/**/*.rs"
# gaze -c 'cargo run -- /' "src/**/*.rs"
# gaze -c 'cargo run -- 31536000 now Monrovia' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 0 1651695664803 tokyo new_y' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 0 1651695664 tokyo new_y' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 2022-01-01T12:23:31 2022-01-01T12:23:31.456' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 2022-01-01T12:23:31 2022-01-01T12:23:31,456' "src/**/*.rs"

gaze -c 'cargo run -- 2022-01-01T12:23:31Z 2022-01-01T12:23:31+0900 2022-01-01T12:23+0900' "src/**/*.rs"

# 2022-01-01T12:23Z     16文字
# 2022-01-01T12:23:31Z  19文字


# RUST_BACKTRACE=1

==> epo-1.0.1.crate: epo-1.0.1/g.sh <==
#! /bin/sh

# gaze -c 'cargo run -- +9 +0 -0500 0 1 100 1000 1970-01-01T00:00:00 1970-01-01T09:00:00 1970-01-01T09:00:00+0900 1970-01-01T00:00:00+0900 "1970/01/01T09:00:00+0000" "2020-04-18T09:00:00+0000" "2020-04-18T09:00:00+0900"' "src/**/*.rs"

# gaze -c 'cargo run' "src/**/*.rs"

# gaze -c 'cargo run -- +9 +0 -0500 0 "2020-04-18T09:00:00+0000"' "src/**/*.rs"

# gaze -c 'cargo run -- +9 +0 -0500 0 "2020-04-18T09:00:00+0000"' "src/**/*.rs"

# gaze -c 'cargo run -- 1650647334 1650647334-3600 1650647334-3600*10' "src/**/*.rs"

# gaze -c 'cargo run -- "now()"' "src/**/*.rs"

# gaze -c 'cargo run -- "array.extract(2..8)"' "src/**/*.rs"

# gaze -c 'ecargo run "[1..10].map(|x| 1650653482 + x * 86400 )"

# gaze -c 'cargo run -- "2022-02-01" "2022-03-01" "2022-04-01" +9 +8 +7 -4 -5 new_y phoe "[1,2,3,4,5]" ' "src/**/*.rs"


# gaze -c 'cargo run -- "[1,2,3,4,5]" ' "src/**/*.rs"
# gaze -c 'cargo run -- "[1,2,3,4,5].map(a=>1650984906+a*86400)" ' "src/**/*.rs"
# gaze -c 'cargo run -- -p "[1,2,3,4,5].map(a=>1650984906+a*86400)" ' "src/**/*.rs"

# gaze -c 'cargo run -- "now" ' "src/**/*.rs"
# gaze -c 'cargo run -- "now*now" ' "src/**/*.rs"
# gaze -c 'cargo run -- -h' "src/**/*.rs"
# gaze -c 'cargo run -- /' "src/**/*.rs"
# gaze -c 'cargo run -- 31536000 now Monrovia' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 0 1651695664803 tokyo new_y' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 0 1651695664 tokyo new_y' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 2022-01-01T12:23:31 2022-01-01T12:23:31.456' "src/**/*.rs"
# gaze -c 'cargo run -- 2022-01-01 2022-01-01T12:23:31 2022-01-01T12:23:31,456' "src/**/*.rs"

# gaze -c 'cargo run -- 2022-01-01T12:23:31Z 2022-01-01T12:23:31+0900 2022-01-01T12:23+0900' "src/**/*.rs"
# gaze -c 'cargo run -- Tokyo' "src/**/*.rs"
# gaze -c 'cargo run -- --version' "src/**/*.rs"
gaze -c 'cargo run -- 2022-04-01' "src/**/*.rs"

# 2022-01-01T12:23Z     16文字
# 2022-01-01T12:23:31Z  19文字


# RUST_BACKTRACE=1
